@@ -1,13 +1,13 @@
 import abc
-import logging as log
+import logging
 from past.builtins import long
 import requests
 from requests import exceptions
 import six
 import xmltodict
 
-#log.basicConfig(level=log.DEBUG)
-log = log.getLogger(__name__)
+
+log = logging.getLogger(__name__)
 
 
 class HttpClient(object):
@@ -19,7 +19,7 @@ class HttpClient(object):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        pass
+        return False
 
     def _do_request(self, http_method, rest_command,
                     parameters=None,
@@ -71,10 +71,10 @@ class HttpClient(object):
             raise
         return response.text
 
-    def _get(self, rest_command, parameters):
+    def _get(self, rest_command, parameters=None):
         return self._do_request('GET', rest_command, parameters)
 
-    def _post(self, rest_command, file):
+    def _post(self, rest_command, file=None):
         return self._do_request('POST', rest_command, file=file)
 
 
@@ -127,10 +127,10 @@ class BaseObjectModel(HttpClient):
         """
         attributes = {}
         for attr in self.__dict__:
-            if (self.__dict__[attr] is not None
-                    or not self.__dict__[attr] == 'endpoint'
-                    or not isinstance(self.__dict__[attr], six.string_types)
-                    or not isinstance(self.__dict__[attr], (int, long))):
+            if (self.__dict__[attr] is not None or not
+                    self.__dict__[attr] == 'endpoint' or not
+                    isinstance(self.__dict__[attr], six.string_types) or not
+                    isinstance(self.__dict__[attr], (int, long))):
                 attributes[attr] = self.__dict__[attr]
         return attributes
 
@@ -189,6 +189,14 @@ class LoadMaster(HttpClient):
         response = self._post('installpatch', file)
         return ApiXmlHelper.is_successful(response)
 
+    def shutdown(self):
+        response = self._get('shutdown')
+        return ApiXmlHelper.is_successful(response)
+
+    def reboot(self):
+        response = self._get('reboot')
+        return ApiXmlHelper.is_successful(response)
+
 
 class KempTechApiError(Exception):
     """Raised if HTTP request has failed."""
